@@ -68,8 +68,7 @@ class Payu():
         if add_charge:
             hash_string += f'{add_charge}|'
 
-        hash_string += f'{self.merchant_salt}|{status}|||||||||||{email}|{first_name}|\
-        {product_info}|{amount}|{txnid}|{response_key}'
+        hash_string += f'{self.merchant_salt}|{status}|||||||||||{email}|{first_name}|{product_info}|{amount}|{txnid}|{response_key}'
         generated_hash = self.generate_hash(hash_string)
         results.update({"return_data": response_data})
         results.update({
